fisx: Class List

fisx

Class List
Here are the classes, structs, unions and interfaces with brief descriptions:
[detail level 12]

▼Nfisx |
C Beam | Class describing an X-ray beam
C Detector | Class describing the detector
C Element |
C Elements | Class handling the physical properties
C EPDL97 |
C Layer | Class containing the composition of a layer
C Material | Class containing the composition of a material
C Math | Common fluorescence spectroscopy math functions
C Ray |
C Shell |
C SimpleIni |
C SimpleSpecfile |
C TransmissionTable |
C XRF |
C XRFConfig |
C ElementsInfo |
C TrasmissionTable | Class containing a transmission table